Anže on Nostr: Day 2 of #adventofcode kinda felt easier than day 1 or was it just me? I got to the ...
Day 2 of #adventofcode kinda felt easier than day 1 or was it just me?
I got to the solution fairly quickly but it was a bit slow. I then spent the next hour optimizing it and managed to make part 1 200x faster and part 2 500x faster 🎉
Published at
2025-12-02 07:11:38 UTCEvent JSON
{
"id": "a010d184c88d6ff3a793f0d1470ef38dddf9dd7ec4efafc6134d26da22864028",
"pubkey": "a39a91945320863e63212c3b4f06a13aa380f33aa231788cf172e6701ba657f4",
"created_at": 1764659498,
"kind": 1,
"tags": [
[
"imeta",
"url https://cdn.fosstodon.org/media_attachments/files/115/648/724/812/057/106/original/3e259d49cffd5208.png",
"m image/png"
],
[
"proxy",
"https://fosstodon.org/@anze3db/115648724870657757",
"web"
],
[
"t",
"adventofcode"
],
[
"proxy",
"https://fosstodon.org/users/anze3db/statuses/115648724870657757",
"activitypub"
],
[
"L",
"pink.momostr"
],
[
"l",
"pink.momostr.activitypub:https://fosstodon.org/users/anze3db/statuses/115648724870657757",
"pink.momostr"
],
[
"-"
]
],
"content": "Day 2 of #adventofcode kinda felt easier than day 1 or was it just me?\n\nI got to the solution fairly quickly but it was a bit slow. I then spent the next hour optimizing it and managed to make part 1 200x faster and part 2 500x faster 🎉\nhttps://cdn.fosstodon.org/media_attachments/files/115/648/724/812/057/106/original/3e259d49cffd5208.png\n",
"sig": "3ab65ac9584bfdc32f235c63f16f2552dd0018092b4b58ea9bb7afa0e3b8a0091afcf8e768f0aeeb9b70cb524892acd51977a6e5546d45e1b8c69d3bae782077"
}